Excluder class

Constructors

Excluder({required List<String> ignoredExtensions, required List<String> ignoredDirs, required bool debug})

Properties

debug ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoredDirs ↔ List<String>
getter/setter pair
ignoredExtensions ↔ List<String>
getter/setter pair
log ↔ Logger
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

containsExcludedDirs(String path) → dynamic
containsIgnoredFileExt(String path) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited